@@ -25,6 +25,7 @@ import platform
 import re
 import signal
 import site
+import shutil
 import sys
 import threading
 import time
@@ -34,6 +35,7 @@ import urllib.parse
 import uuid
 import zipfile
 import asyncio
+import zipfile
 from watchgod import awatch
 
 # Optional web servers for speed
@@ -351,15 +353,16 @@ class Flash(Fixture):
         flash = request.get_cookie("py4web-flash")
         if flash:
             Flash.local.flash = json.loads(flash)
-            response.delete_cookie("py4web-flash")
         else:
             Flash.local.flash = None
 
     def on_success(self, status):
         # if we redirect and have a flash message we move it to the session
         if status == 303 and Flash.local.flash:
-            response.set_cookie("py4web-flash", json.dumps(Flash.local.flash))
+            response.set_cookie("py4web-flash", json.dumps(Flash.local.flash), path="/")
             Flash.local.flash = None
+        else:
+            response.delete_cookie("py4web-flash", path="/")
 
     def set(self, message, class_="", sanitize=True):
         # we set a flash message
@@ -369,11 +372,13 @@ class Flash(Fixture):
 
     def transform(self, data, shared_data=None):
         # if we have a valid flash message, we inject it in the response dict
-        if Flash.local.flash:
-            if isinstance(data, dict):
-                data["flash"] = Flash.local.flash
-            else:
-                response.headers["py4web-flash"] = json.dumps(Flash.local.flash)
+        if isinstance(data, dict):
+            if not "flash" in data:
+                data["flash"] = Flash.local.flash or ""
+        else:
+            if Flash.local.flash is not None:
+                response.headers["component-flash"] = json.dumps(Flash.local.flash)
+        Flash.local.flash = None
         return data
 
 
@@ -437,7 +442,9 @@ class Template(Fixture):
 
 class Session(Fixture):
 
-    # All apps share the same default secret if not specified. important for _dashboard reload
+    # All apps share the same default secret if not specified.
+    # important for _dashboard reload
+    # the actual value is loaded from a file
     SECRET = None
 
     def __init__(
@@ -454,10 +461,8 @@ class Session(Fixture):
         (optional) storage must have a get(key) and set(key,value,expiration) methods
         if not provided session is stored in jwt cookie else the jwt is stored in storage and its uuid key is stored in the cookie
         """
-        if not secret and not storage:
-            # when no secret is specified: one time sessions
-            secret = Session.SECRET = Session.SECRET or str(uuid.uuid1())
-        self.secret = secret
+        # assert Session.SECRET, "Missing Session.SECRET"
+        self.secret = secret or Session.SECRET
         self.expiration = expiration
         self.algorithm = algorithm
         self.local = threading.local()
@@ -498,12 +503,15 @@ class Session(Fixture):
                     assert self.local.data["timestamp"] > time.time() - int(
                         self.expiration
                     )
-                assert self.local.data.get("secure") == self.local.secure
+                assert self.get_data().get("secure") == self.local.secure
             except Exception:
                 pass
-        if not "uuid" in self.local.data:
+        if not "uuid" in self.get_data():
             self.clear()
 
+    def get_data(self):
+        return getattr(self.local, 'data', {})
+
     def save(self):
         self.local.data["timestamp"] = time.time()
         if self.storage:
@@ -523,13 +531,13 @@ class Session(Fixture):
         )
 
     def get(self, key, default=None):
-        return self.local.data.get(key, default)
+        return self.get_data().get(key, default)
 
     def __getitem__(self, key):
-        return self.local.data[key]
+        return self.get_data()[key]
 
     def __delitem__(self, key):
-        if key in self.local.data:
+        if key in self.get_data():
             self.local.changed = True
             del self.local.data[key]
 
@@ -538,10 +546,10 @@ class Session(Fixture):
         self.local.data[key] = value
 
     def keys(self):
-        return self.local.data.keys()
+        return self.get_data().keys()
 
     def __iter__(self):
-        return self.local.data.items()
+        return self.get_data().items()
 
     def clear(self):
         self.local.changed = True
@@ -587,11 +595,14 @@ def URL(
         request.environ.get("HTTP_X_SCRIPT_NAME", "")
         or request.environ.get("SCRIPT_NAME", "")
     ).rstrip("/")
-    prefix = script_name + (
-        "/%s/" % request.app_name
-        if (request.app_name != "_default" and use_appname)
-        else "/"
-    )
+    if parts and parts[0].startswith('/'):
+        prefix = ''
+    else:
+        prefix = script_name + (
+            "/%s/" % request.app_name
+            if (request.app_name != "_default" and use_appname)
+            else "/"
+            )
     broken_parts = []
     for part in parts:
         broken_parts += str(part).rstrip("/").split("/")
@@ -604,7 +615,7 @@ def URL(
         if static_version:
             broken_parts.insert(1, "_" + static_version)
 
-    url = prefix + "/".join(map(lambda x: urllib.parse.quote(x), broken_parts))
+    url = prefix + "/".join(map(urllib.parse.quote, broken_parts))
     # Signs the URL if required.  Copy vars into urlvars not to modify it.
     urlvars = {k: v for k, v in vars.items()} if vars else {}
     if signer:
@@ -617,7 +628,7 @@ def URL(
         url += "#%s" % hash
     if not scheme is False:
         original_url = request.environ.get("HTTP_ORIGIN") or request.url
-        orig_scheme, _, domain = original_url.split("/")[:3]
+        orig_scheme, _, domain = original_url.split("/", 3)[:3]
         scheme = (
             orig_scheme if scheme is True else "" if scheme is None else scheme + ":"
         )
@@ -676,7 +687,7 @@ class action:
         def decorator(func):
             @functools.wraps(func)
             def wrapper(*args, **kwargs):
-                # data shared by all fixtures in the piplined for each request
+                # data shared by all fixtures in the pipeline for each request
                 shared_data = {"template_context": {}}
                 try:
                     [obj.on_request() for obj in fixtures]
@@ -1020,15 +1031,15 @@ class Reloader:
                 module = importlib.machinery.SourceFileLoader(
                     module_name, init
                 ).load_module()
-                click.echo("\x1b[A[X] loaded %s       " % app_name, color="green")
+                click.secho("\x1b[A[X] loaded %s       " % app_name, fg="green")
                 Reloader.MODULES[app_name] = module
                 Reloader.ERRORS[app_name] = None
             except:
                 tb = traceback.format_exc()
                 print(tb)
-                click.echo(
+                click.secho(
                     "\x1b[A[FAILED] loading %s       \n%s\n" % (app_name, tb),
-                    color="red",
+                    fg="red",
                 )
                 Reloader.ERRORS[app_name] = tb
                 # clear all files/submodules if the loading fails
@@ -1225,7 +1236,9 @@ def start_server(args):
             logging.error("gevent not installed")
             return
         server_config = "windows"
-        params["server"] = "gevent"
+        params["server"] = "tornado"
+        if sys.version_info >= (3, 8):  #see  https://bugs.python.org/issue37373 FIX: tornado/py3.8 on windows
+            asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
     elif number_workers < 1:
         server_config = "tornado"
         params["server"] = "tornado"
@@ -1324,13 +1337,6 @@ def wsgi(**args):
 #########################################################################################
 
 
-def fix_ansi_on_windows():
-    if platform.system().lower() == "windows":  # fix for ANSI on Win7, 8, 10 ...
-        from ctypes import windll
-
-        windll.kernel32.SetConsoleMode(windll.kernel32.GetStdHandle(-11), 7)
-
-
 def keyboardInterruptHandler(signal, frame):
     """Catch interrupts like Ctrl-C"""
     click.echo(
@@ -1385,7 +1391,6 @@ def setup(**args):
 def shell(apps_folder):
     """Open a python shell with apps_folder added to the path"""
     install_args(dict(apps_folder=apps_folder))
-    fix_ansi_on_windows()
     code.interact(local=dict(globals(), **locals()))
 
 
@@ -1431,6 +1436,33 @@ def set_password(password, password_file):
     with open(password_file, "w") as fp:
         fp.write(str(pydal.validators.CRYPT()(password)[0]))
 
+@cli.command()
+@click.argument("apps_folder", default="apps")
+@click.argument("app_name")
+@click.option(
+    "-s",
+    "--scaffold_zip",
+    default=None,
+    help="Path to the zip with the scaffolding app",
+    show_default=False,
+)
+def new_app(apps_folder, app_name, scaffold_zip):
+    source = scaffold_zip or os.path.join(
+        os.path.dirname(__file__), 
+        'assets',
+        "py4web.app._scaffold.zip")
+    target_dir = os.path.join(apps_folder, app_name)
+    if not os.path.exists(source):
+        click.echo("Source app %s does not exists" % source)
+        sys.exit(1)
+    elif os.path.exists(target_dir):
+        click.echo("Target folder %s already exists" % target_dir)
+        sys.exit(1)
+    else:
+        zfile = zipfile.ZipFile(source, "r")
+        zfile.extractall(target_dir)
+        zfile.close()
+
 
 @cli.command()
 @click.argument("apps_folder", default="apps")
@@ -1486,7 +1518,7 @@ def run(**args):
 
     from py4web import __version__
 
-    click.echo(ART, color="blue")
+    click.secho(ART, fg="blue")
     click.echo("Py4web: %s on Python %s\n\n" % (__version__, sys.version))
 
     # If we know where the password is stored, read it, otherwise ask for one
