@@ -4,7 +4,9 @@ import time
 import uuid
 import copy
 from py4web import request, response
+from py4web.utils.param import Param
 from pydal.validators import Validator
+
 from yatl.helpers import (
     A,
     TEXTAREA,
@@ -98,7 +100,7 @@ class FormStyleFactory:
                 if not field.readable:
                     continue
             # if this is an create form (unkown id) then only show writable fields
-            elif not vars.get('id'):
+            elif not vars.get("id"):
                 if not field.writable:
                     continue
             # ignore blob fields
@@ -207,6 +209,7 @@ class FormStyleFactory:
                     _class=field_class,
                     _placeholder=placeholder,
                     _title=title,
+                    _autocomplete="off" if field_type == "password" else "on",
                 )
 
             key = control.name.rstrip("/")
@@ -249,7 +252,7 @@ class FormStyleFactory:
                     )
                 )
 
-            if vars.get('id'):
+            if vars.get("id"):
                 form.append(INPUT(_name="id", _value=vars["id"], _hidden=True))
         if deletable:
             controls["delete"] = INPUT(
@@ -300,9 +303,9 @@ def FormStyleBulma(table, vars, errors, readonly, deletable):
         "input[type=radio]": "radio",
         "input[type=checkbox]": "checkbox",
         "input[type=submit]": "button",
-        "input[type=password]": "password",
+        "input[type=password]": "input password",
         "input[type=file]": "file",
-        "select": "select",
+        "select": "control select",
         "textarea": "textarea",
     }
     return FormStyleDefault(table, vars, errors, readonly, deletable, classes)
@@ -381,7 +384,11 @@ class Form(object):
         csrf_session=None,
         lifespan=None,
         signing_info=None,
+        submit_value="Submit",
     ):
+        self.param = Param(
+            formstyle=formstyle, hidden=hidden, submit_value=submit_value, sidecar=[],
+        )
 
         if isinstance(table, list):
             dbio = False
@@ -396,24 +403,26 @@ class Form(object):
         else:
             self.record = record
 
+        # computed from input and not changed
         self.table = table
-        self.readonly = readonly
         self.deletable = deletable and not readonly and self.record
-        self.formstyle = formstyle
         self.dbio = dbio
         self.keep_values = True if keep_values or self.record else False
+        self.form_name = form_name or table._tablename
+        self.csrf_session = csrf_session
+        self.signing_info = signing_info
+        self.validation = validation
+        self.lifespan = lifespan
+
+        # initialized and can change
         self.vars = {}
         self.errors = {}
+        self.readonly = readonly
         self.submitted = False
         self.deleted = False
         self.accepted = False
-        self.form_name = form_name or table._tablename
-        self.hidden = hidden
         self.formkey = None
         self.cached_helper = None
-        self.csrf_session = csrf_session
-        self.lifespan = lifespan
-        self.signing_info = signing_info
         self.action = None
 
         if readonly or request.method == "GET":
@@ -499,7 +508,7 @@ class Form(object):
             key = request.get_cookie("_form_key")
             if key is None:
                 key = str(uuid.uuid1())
-                response.set_cookie("_form_key", key)
+                response.set_cookie("_form_key", key, same_site="Strict")
         additional_info = {
             "signing_info": self.signing_info,
             "form_name": self.form_name,
@@ -547,11 +556,15 @@ class Form(object):
         if self.accepted:
             self.clear()
         if not self.cached_helper:
-            helper = self.formstyle(
+            helper = self.param.formstyle(
                 self.table, self.vars, self.errors, self.readonly, self.deletable
             )
+            for item in self.param.sidecar:
+                helper["form"][-1][-1].append(item)
             if self.action:
                 helper["_action"] = self.action
+            if self.param.submit_value:
+                helper["controls"]["submit"]["_value"] = self.param.submit_value
             if self.form_name:
                 helper["controls"]["hidden_widgets"]["formname"] = INPUT(
                     _type="hidden", _name="_formname", _value=self.form_name
@@ -562,12 +575,11 @@ class Form(object):
                     _type="hidden", _name="_formkey", _value=self.formkey
                 )
                 helper["form"].append(helper["controls"]["hidden_widgets"]["formkey"])
-            for key in self.hidden or {}:
+            for key in self.param.hidden or {}:
                 helper["controls"]["hidden_widgets"][key] = INPUT(
-                    _type="hidden", _name=key, _value=self.hidden[key]
+                    _type="hidden", _name=key, _value=self.param.hidden[key]
                 )
                 helper["form"].append(helper["controls"]["hidden_widgets"][key])
-
             helper["controls"]["begin"] = XML(
                 "".join(
                     str(helper["controls"]["begin"])
@@ -583,8 +595,12 @@ class Form(object):
     def custom(self):
         return self.helper()["controls"]
 
+    @property
+    def structure(self):
+        return self.helper()["form"]
+
     def xml(self):
-        return self.helper()["form"].xml()
+        return self.structure.xml()
 
     def __str__(self):
         return self.xml()
